==> v11.1.2.zip: brewman/overlord/src/app/issue/issue-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { CostCentreListResolver } from '../cost-centre/cost-centre-list-resolver.service';

import { IssueResolver } from './issue-resolver.service';
import { IssueComponent } from './issue.component';

const issueRoutes: Routes = [
  {
    path: '',
    component: IssueComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Issue',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(IssueResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
    runGuardsAndResolvers: 'always',
  },
  {
    path: ':id',
    component: IssueComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Issue',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(IssueResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
    runGuardsAndResolvers: 'always',
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(issueRoutes)],
  exports: [RouterModule],
  providers: [IssueResolver],
})
export class IssueRoutingModule {}

==> v11.1.5.zip: brewman/overlord/src/app/issue/issue-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { CostCentreListResolver } from '../cost-centre/cost-centre-list-resolver.service';

import { IssueResolver } from './issue-resolver.service';
import { IssueComponent } from './issue.component';

const issueRoutes: Routes = [
  {
    path: '',
    component: IssueComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Issue',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(IssueResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
    runGuardsAndResolvers: 'always',
  },
  {
    path: ':id',
    component: IssueComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Issue',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(IssueResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
    runGuardsAndResolvers: 'always',
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(issueRoutes)],
  exports: [RouterModule],
  providers: [IssueResolver],
})
export class IssueRoutingModule {}
